@@ -12,9 +12,12 @@ class Parser:
             Container for a callable boolean predicate
             along with the topic names being evaluated
         '''
+        last_state = None
+        
         def __call__(self, *args, **kw):
             'Syntactic sugar'
-            return self.expr(*args, **kw)
+            self.last_state = self.expr(*args, **kw)
+            return self.last_state
             
         def __hash__(self):
             return hash(self.expr)
